==> plato_mongo_dart-0.3.3.tar.gz: lib/mongo_dart.dart <==
/// Server-side driver library for MongoDb implemented in pure Dart.
/// As most of IO in Dart, mongo_dart is totally async -using Futures and Streams.
/// .

library mongo_dart;

import 'dart:io';
import 'dart:async';
import 'dart:math';
import 'package:crypto/crypto.dart' as crypto;
import 'dart:collection';
import 'package:bson/bson.dart';
import 'package:logging/logging.dart';
import 'package:mongo_dart_query/mongo_dart_query.dart';
import 'package:pool/pool.dart';
import 'dart:convert';
import 'dart:typed_data';
import "package:collection/collection.dart";

export 'package:bson/bson.dart';
export 'package:mongo_dart_query/mongo_dart_query.dart';

part 'src/network/packet_converter.dart';
part 'src/network/connection_manager.dart';
part 'src/network/connection.dart';
part 'src/network/mongo_message_transformer.dart';
part 'src/database/mongo_message.dart';
part 'src/database/mongo_query_message.dart';
part 'src/database/mongo_reply_message.dart';
part 'src/database/mongo_insert_message.dart';
part 'src/database/mongo_remove_message.dart';
part 'src/database/mongo_getmore_message.dart';
part 'src/database/mongo_kill_cursors_message.dart';
part 'src/database/mongo_update_message.dart';
part 'src/database/server_config.dart';
part 'src/database/dbcommand.dart';
part 'src/database/db.dart';
part 'src/database/error.dart';
part 'src/database/state.dart';
part 'src/database/dbcollection.dart';
part 'src/database/cursor.dart';
part 'src/gridfs/gridfs.dart';
part 'src/gridfs/grid_file.dart';
part 'src/gridfs/grid_in.dart';
part 'src/gridfs/grid_out.dart';
part 'src/gridfs/chunk_handler.dart';
part 'src/auth/auth.dart';
part 'src/auth/sasl_authenticator.dart';
part 'src/auth/scram_sha1_authenticator.dart';
part 'src/auth/mongodb_cr_authenticator.dart';
part 'src/connection_pool.dart';

==> plato_mongo_dart-0.3.4.tar.gz: lib/mongo_dart.dart <==
/// Server-side driver library for MongoDb implemented in pure Dart.
/// As most of IO in Dart, mongo_dart is totally async -using Futures and Streams.
/// .

library mongo_dart;

import 'dart:io';
import 'dart:async';
import 'dart:math';
import 'package:crypto/crypto.dart' as crypto;
import 'dart:collection';
import 'package:plato_bson/bson.dart';
import 'package:logging/logging.dart';
import 'package:mongo_dart_query/mongo_dart_query.dart';
import 'package:pool/pool.dart';
import 'dart:convert';
import 'dart:typed_data';
import "package:collection/collection.dart";

export 'package:plato_bson/bson.dart';
export 'package:mongo_dart_query/mongo_dart_query.dart';

part 'src/network/packet_converter.dart';
part 'src/network/connection_manager.dart';
part 'src/network/connection.dart';
part 'src/network/mongo_message_transformer.dart';
part 'src/database/mongo_message.dart';
part 'src/database/mongo_query_message.dart';
part 'src/database/mongo_reply_message.dart';
part 'src/database/mongo_insert_message.dart';
part 'src/database/mongo_remove_message.dart';
part 'src/database/mongo_getmore_message.dart';
part 'src/database/mongo_kill_cursors_message.dart';
part 'src/database/mongo_update_message.dart';
part 'src/database/server_config.dart';
part 'src/database/dbcommand.dart';
part 'src/database/db.dart';
part 'src/database/error.dart';
part 'src/database/state.dart';
part 'src/database/dbcollection.dart';
part 'src/database/cursor.dart';
part 'src/gridfs/gridfs.dart';
part 'src/gridfs/grid_file.dart';
part 'src/gridfs/grid_in.dart';
part 'src/gridfs/grid_out.dart';
part 'src/gridfs/chunk_handler.dart';
part 'src/auth/auth.dart';
part 'src/auth/sasl_authenticator.dart';
part 'src/auth/scram_sha1_authenticator.dart';
part 'src/auth/mongodb_cr_authenticator.dart';
part 'src/connection_pool.dart';
